<template>
	<div class="echarts-wrapper" @click="toParentPage">
		<div class="echarts-content" ref="chart"></div>
	</div>
</template>

<script>
import * as echarts from 'echarts';
import { WebSocketClass } from '@/assets/js/socket'
export default {
	name: "RoseChartHea",
	chart: "",
	chartData: [],
	props: {
		id: {
			type: String,
			default: ""
		}
	},
	data() {
		return {
			websock: null
		}
	},
	methods: {
		toParentPage() {
			window.parent.parent.postMessage({
				cmd: "syncPage",
				params: {
					pageInfo: {
						label: "落后单体查询",
						name: "taskplan",
						src: "#/reportStatistics/taskplan",
						closable: true
					},
				}
			}, "*");
		},
		setOption(opt) {
			this.$options.chart.setOption(opt);
		},
		organizeData(data) {
			let option = {
				tooltip: {
					trigger: 'item'
				},
				series: [{
					type: 'pie',
					center: ['50%', '50%'],
					radius: ['0', '50%'],
					itemStyle: {
						color(params) {
							return data[params.dataIndex].color;
						},
					},
					data: data
				}]
			};

			// 设置图表配置项
			this.setOption(option);
		},
		setData(sendData) {
			if (sendData) {
				this.$options.chartData = sendData;
				this.organizeData(sendData)
			} else {
				this.postData()
			}
		},
		postData() {
			let userId = localStorage.getItem('userId');
			this.websock = new WebSocketClass(`/screen/batteryData/capStatus/${userId}`, this.wsMessage, 4000)
		},
		wsMessage(res) {
			if (res.code == 1) {
				let optionData = [{
					value: 0,
					name: '单体容量告警',
					color: '#E85D22'
				},
				{
					value: 0,
					name: '单体容量更换',
					color: '#76CFDD'
				},
				{
					value: 0,
					name: '单体容量健康',
					color: '#FEDB5B'
				},
				]
				let resData = res.data;
				for (let key in resData) {
					optionData.map(item => {
						if (item.name == key) {
							item.value = resData[key]
						}
					})
				}
				this.$options.chartData = optionData;
				this.organizeData(optionData)
			}
		},
		outClear() {
			this.websock.closeMyself()
			this.websock = null
			window.removeEventListener('resize', this.resize);
		},
		resize() {
			setTimeout(() => {
				this.$options.chart.resize();
				if (JSON.stringify(this.$options.chartData) != '{}') {
					this.setData(this.$options.chartData);
				}
			}, 300)
		}
	},
	mounted() {
		// 基于准备好的dom，初始化echarts实例
		this.$options.chart = echarts.init(this.$refs.chart);

		window.addEventListener('resize', this.resize);
	},
	destroyed() {
		window.removeEventListener('resize', this.resize);
	}
}
</script>

<style scoped>
</style>